import { Component } from '@angular/core';
import { RouterOutlet, RouterLink } from '@angular/router';
import { RecipeFormComponent } from './components/recipe-form/recipe-form.component';
import { RecipeService } from './services/recipe.service';
import { Recipe } from './model/recipe.model';
import { RecipeListComponent } from './components/recipe-list/recipe-list.component';
import { TranslocoPipe, TranslocoService } from '@jsverse/transloco';

@Component({
  selector: 'app-root',
  standalone: true,
  imports: [
    RouterOutlet,
    RouterLink,
    RecipeFormComponent,
    RecipeListComponent,
    TranslocoPipe,
  ],
  providers: [RecipeService, TranslocoService],
  templateUrl: './app.component.html',
  styleUrl: './app.component.css'
})
export class AppComponent {
  title = 'bromista-nisqa-receta';

  constructor(protected recipeService: RecipeService, private translocoService: TranslocoService){}

  addRecipe($event: Recipe): void {
    this.recipeService.addRecipe($event);
  }

  changeLanguage(event: Event) {
    if (event.target && event.target instanceof HTMLSelectElement) {
      const lang = event.target.value;
      this.translocoService.setActiveLang(lang);
    } else {
      console.log('Error on language option value')
    }
  }
}
